[![CircleCI](https://circleci.com/gh/conanfanli/pyolice.svg?style=svg)](https://circleci.com/gh/conanfanli/pyolice)
[![codecov](https://codecov.io/gh/conanfanli/pyolice/branch/master/graph/badge.svg)](https://codecov.io/gh/conanfanli/pyolice)

# pyolice
Python code police: check source code for crimes

